package com.flossom.common.core.mapper;


import com.flossom.common.core.domain.entity.CtLeaveMessage;

import java.util.List;

/**
 * 共创管理-留言管理Mapper接口
 *
 * @author flossom
 * @date 2023-12-11
 */
public interface CtLeaveMessageMapper
{
    /**
     * 查询共创管理-留言管理
     *
     * @param id 共创管理-留言管理主键
     * @return 共创管理-留言管理
     */
    public CtLeaveMessage selectCtLeaveMessageById(Long id);

    /**
     * 查询共创管理-留言管理列表
     *
     * @param ctLeaveMessage 共创管理-留言管理
     * @return 共创管理-留言管理集合
     */
    public List<CtLeaveMessage> selectCtLeaveMessageList(CtLeaveMessage ctLeaveMessage);

    /**
     * 新增共创管理-留言管理
     *
     * @param ctLeaveMessage 共创管理-留言管理
     * @return 结果
     */
    public int insertCtLeaveMessage(CtLeaveMessage ctLeaveMessage);

    /**
     * 修改共创管理-留言管理
     *
     * @param ctLeaveMessage 共创管理-留言管理
     * @return 结果
     */
    public int updateCtLeaveMessage(CtLeaveMessage ctLeaveMessage);

    /**
     * 删除共创管理-留言管理
     *
     * @param id 共创管理-留言管理主键
     * @return 结果
     */
    public int deleteCtLeaveMessageById(Long id);

    /**
     * 批量删除共创管理-留言管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCtLeaveMessageByIds(Long[] ids);

    /**
     * 查询共创管理-留言管理列表根据对应条件
     *
     * @param ctLeaveMessage 共创管理-留言管理
     * @return 共创管理-留言管理集合
     */
    public List<CtLeaveMessage> selectCtLeaveMessageByCondition(CtLeaveMessage ctLeaveMessage);
}
